@@ -12,7 +12,6 @@
 #' @param  startindex  return the subset of the matching records that starts at
 #'    the supplied (zero-based index).
 #' @param maxresults max number of results to return
-#' @param url the base GBIF API url for the function (should be left to default)
 #' @examples \dontrun{
 #' # Test the function for a few networks
 #' networks(maxresults=10)
@@ -25,11 +24,11 @@
 #' }
 #' @export
 networks <- function(name = "", code = NULL, modifiedsince = NULL,
-    startindex = NULL, maxresults = NULL,
-		url = "http://data.gbif.org/ws/rest/network/list")
+    startindex = NULL, maxresults = NULL)
 {
+	url = "http://data.gbif.org/ws/rest/network/list"
 	args <- compact(list(name = name, code=code, modifiedsince = modifiedsince,
-											 startindex = startindex, maxresults = maxresults))
+						 startindex = startindex, maxresults = maxresults))
 	temp <- getForm(url, .params=args)
 	tt <- xmlParse(temp)
 	names_ <- xpathSApply(tt, "//gbif:resourceNetwork/gbif:name",
