@@ -16,7 +16,6 @@
 #' @param  startindex  return the subset of the matching records that starts at
 #'    the supplied (zero-based index).
 #' @param maxresults max number of results to return
-#' @param url the base GBIF API url for the function (should be left to default)
 #' @examples \dontrun{
 #' # Test the function for a few resources
 #' resources(maxresults=30)
@@ -30,9 +29,9 @@
 #' }
 #' @export
 resources <- function(name = "", providerkey = NULL, basisofrecordcode = NULL,
-   modifiedsince = NULL,  startindex = NULL, maxresults = NULL,
-   url = "http://data.gbif.org/ws/rest/resource/list")
+   modifiedsince = NULL,  startindex = NULL, maxresults = NULL)
 {
+	url = "http://data.gbif.org/ws/rest/resource/list"
 	args <- compact(list(name = name, providerkey = providerkey,
 											 basisofrecordcode = basisofrecordcode,
 											 modifiedsince = modifiedsince, startindex = startindex,
